/*-------------------------------------------------------------------------+
| Copyright 2020 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.views.fx;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Map;
import java.util.Map.Entry;

import org.fortiss.tooling.common.ui.javafx.control.treetableview.DynamicTreeContentProviderBase;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation.ESeverity;
import org.fortiss.tooling.kernel.ui.service.IMarkerService;

/**
 * Content provider for the error marker view.
 * 
 * @author abid
 */
public class MarkerViewFXContentProvider extends DynamicTreeContentProviderBase<Object> {

	/** {@inheritDoc} */
	@SuppressWarnings("unchecked")
	@Override
	public Collection<? extends Object> getChildren(Object parent) {
		Map<ESeverity, Boolean> servList;
		Collection<IConstraintViolation<?>> violation_list =
				new ArrayList<IConstraintViolation<?>>();
		if(parent instanceof Map<?, ?>) {
			servList = (Map<ESeverity, Boolean>)parent;
			for(Entry<ESeverity, Boolean> e : servList.entrySet()) {
				if(e.getValue()) {
					violation_list.addAll(
							IMarkerService.getInstance().getAllViolationsWithSeverity(e.getKey()));
				}
			}
			return violation_list;
		}
		return null;
	}
}
